'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = _interopDefault(require('react'));
var styled = require('styled-components');
var styled__default = _interopDefault(styled);
var PropTypes = _interopDefault(require('prop-types'));

var taggedTemplateLiteral = function (strings, raw) {
  return Object.freeze(Object.defineProperties(strings, {
    raw: {
      value: Object.freeze(raw)
    }
  }));
};

var toConsumableArray = function (arr) {
  if (Array.isArray(arr)) {
    for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) arr2[i] = arr[i];

    return arr2;
  } else {
    return Array.from(arr);
  }
};

/*
 * @license
 * Copyright OAH Technology. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */

var badge = PropTypes.shape({
  status: colorState,
  title: PropTypes.string,
  position: position
});
var position = PropTypes.oneOf(['topRight', 'topLeft', 'bottomRight', 'bottomLeft', 'topStart', 'topEnd', 'bottomStart', 'bottomEnd']);

var colorState = PropTypes.oneOf(['Info', 'Success', 'Danger', 'Primary', 'Warning', 'Disabled']);

var placement = PropTypes.oneOf(['start', 'end', 'right', 'left', 'top', 'bottom']);

var trigger = PropTypes.oneOf(['click', 'hover', 'focus']);

var statusArray = ['Info', 'Success', 'Danger', 'Primary', 'Warning'];

var size = PropTypes.oneOf(['XXS', 'XS', 'SM', 'MD', 'LG', 'XL', 'XXL']);

var shape = PropTypes.oneOf(['Rectangle', 'SemiRound', 'Round']);

var itemType = {
  title: PropTypes.string.isRequired,
  link: PropTypes.any,
  expanded: PropTypes.bool,
  group: PropTypes.bool,
  hidden: PropTypes.bool,
  icon: PropTypes.string,
  target: PropTypes.string,
  url: PropTypes.string
};

var buttonTypes = {
  fullWidth: PropTypes.bool,
  hero: PropTypes.bool,
  outline: PropTypes.bool,
  pulse: PropTypes.bool,
  size: PropTypes.oneOf(['XS', 'SM', 'MD', 'LG']),
  shape: shape,
  status: PropTypes.oneOf([].concat(statusArray, ['Secondary']))
};

var _templateObject = taggedTemplateLiteral(['\n  ', '\n'], ['\n  ', '\n']),
    _templateObject2 = taggedTemplateLiteral(['\n    display: flex;\n    flex-direction: column;\n    position: relative;\n\n    font-size: ', ';\n    line-height: ', ';\n    font-weight: ', ';\n\n    background: ', ';\n    color: ', ';\n    margin-bottom: ', ';\n    border-radius: ', ';\n    box-shadow: ', ';\n    padding: ', ';\n\n    ', '\n\n    ', '\n\n    ', '\n\n    ', '\n\n    .close {\n      padding: ', ';\n      font-size: 1.5rem;\n      line-height: 1;\n      cursor: pointer;\n      font-family: monospace;\n\n      position: absolute;\n      top: 0;\n      ', ': 0;\n      color: inherit;\n      background-color: transparent;\n      border: 0;\n      -webkit-appearance: none;\n    }\n    ', '\n  '], ['\n    display: flex;\n    flex-direction: column;\n    position: relative;\n\n    font-size: ', ';\n    line-height: ', ';\n    font-weight: ', ';\n\n    background: ', ';\n    color: ', ';\n    margin-bottom: ', ';\n    border-radius: ', ';\n    box-shadow: ', ';\n    padding: ', ';\n\n    ', '\n\n    ', '\n\n    ', '\n\n    ', '\n\n    .close {\n      padding: ', ';\n      font-size: 1.5rem;\n      line-height: 1;\n      cursor: pointer;\n      font-family: monospace;\n\n      position: absolute;\n      top: 0;\n      ', ': 0;\n      color: inherit;\n      background-color: transparent;\n      border: 0;\n      -webkit-appearance: none;\n    }\n    ', '\n  ']),
    _templateObject3 = taggedTemplateLiteral(['\n        background-color: ', ';\n        color: ', ';\n      '], ['\n        background-color: ', ';\n        color: ', ';\n      ']),
    _templateObject4 = taggedTemplateLiteral(['\n        border-top-style: solid;\n        border-top-width: ', ';\n        border-top-color: ', ';\n      '], ['\n        border-top-style: solid;\n        border-top-width: ', ';\n        border-top-color: ', ';\n      ']),
    _templateObject5 = taggedTemplateLiteral(['\n        border: 2px solid ', ';\n      '], ['\n        border: 2px solid ', ';\n      ']),
    _templateObject6 = taggedTemplateLiteral(['\n        padding-right: ', ';\n      '], ['\n        padding-right: ', ';\n      ']);

var AlertStyle = styled__default.div(_templateObject, function (_ref) {
  var theme = _ref.theme,
      size$$1 = _ref.size,
      status = _ref.status,
      accent = _ref.accent,
      outline = _ref.outline,
      closable = _ref.closable;
  return styled.css(_templateObject2, theme.alertFontSize, theme.alertLineHeight, theme.alertFontWeight, theme.alertBg, theme.alertOutlineFg, theme.alertMargin, theme.alertBorderRadius, theme.alertShadow, theme.alertPadding, size$$1 && 'height: ' + theme['alertHeight' + size$$1] + ';', status && styled.css(_templateObject3, theme['alert' + status + 'Bg'], status === 'Disabled' ? theme.alertDisabledFg : theme.alertFg), accent && styled.css(_templateObject4, theme.alertBorderRadius, theme['alert' + accent + 'Bg']), outline && styled.css(_templateObject5, theme['alert' + outline + 'Bg']), theme.alertPadding, theme.dir === 'rtl' ? 'left' : 'right', closable && styled.css(_templateObject6, theme.alertClosablePadding));
});

function Alert(props) {
  return React.createElement(
    AlertStyle,
    props,
    props.closable && React.createElement(
      'button',
      {
        onClick: props.onClose,
        type: 'button',
        className: 'close',
        'aria-label': 'Close'
      },
      React.createElement(
        'span',
        { 'aria-hidden': 'true' },
        '\xD7'
      )
    ),
    props.children
  );
}
var status = PropTypes.oneOf([].concat(toConsumableArray(statusArray), ['Active', 'Disabled']));
Alert.propTypes = {
  size: size,
  status: status,
  accent: status,
  outline: status,
  closable: PropTypes.bool,
  onClose: PropTypes.func
};

module.exports = Alert;
