'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var PropTypes = _interopDefault(require('prop-types'));
var styled = require('styled-components');
var styled__default = _interopDefault(styled);

var _extends = Object.assign || function (target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i];

    for (var key in source) {
      if (Object.prototype.hasOwnProperty.call(source, key)) {
        target[key] = source[key];
      }
    }
  }

  return target;
};

var taggedTemplateLiteral = function (strings, raw) {
  return Object.freeze(Object.defineProperties(strings, {
    raw: {
      value: Object.freeze(raw)
    }
  }));
};

var _templateObject = taggedTemplateLiteral(['\n      @media (max-width: ', 'px) {\n        ', '\n      }\n    '], ['\n      @media (max-width: ', 'px) {\n        ', '\n      }\n    ']),
    _templateObject2 = taggedTemplateLiteral(['\n      @media (min-width: ', 'px) {\n        ', '\n      }\n    '], ['\n      @media (min-width: ', 'px) {\n        ', '\n      }\n    ']),
    _templateObject3 = taggedTemplateLiteral(['\n      @media (min-width: ', 'px) and (max-width: ', 'px) {\n        ', '\n      }\n    '], ['\n      @media (min-width: ', 'px) and (max-width: ', 'px) {\n        ', '\n      }\n    ']);
var gridSize = 12;
var gridGutter = 24;
var breakpoints = {
  xs: 0,
  is: 400,
  sm: 576,
  md: 768,
  lg: 992,
  xl: 1200,
  xxl: 1400,
  xxxl: 1600
};

var maxContainer = {
  is: 380,
  sm: 540,
  md: 720,
  lg: 960,
  xl: 1140,
  xxl: 1320,
  xxxl: 1500
};
function getGridSize(theme) {
  return theme.gridSize ? theme.gridSize : gridSize;
}
function getGridGutter(theme) {
  return theme.gridGutter ? theme.gridGutter : gridGutter;
}
function breakpointMin(name) {
  return breakpoints[name] != 0 ? breakpoints[name] : null;
}
var breakpointUp = function breakpointUp(name) {
  return function () {
    var min = breakpointMin(name);
    if (min) {
      return styled.css(_templateObject2, min, styled.css.apply(undefined, arguments));
    } else {
      return styled.css.apply(undefined, arguments);
    }
  };
};

var _templateObject$1 = taggedTemplateLiteral(['\n  ', '\n'], ['\n  ', '\n']),
    _templateObject2$1 = taggedTemplateLiteral(['\n        max-width: ', 'px;\n      '], ['\n        max-width: ', 'px;\n      ']),
    _templateObject3$1 = taggedTemplateLiteral(['\n  ', '\n  margin-right: auto;\n  margin-left: auto;\n  width: 100%;\n  ', '\n'], ['\n  ', '\n  margin-right: auto;\n  margin-left: auto;\n  width: 100%;\n  ', '\n']),
    _templateObject4 = taggedTemplateLiteral(['\n    padding-right: ', 'px;\n    padding-left: ', 'px;\n  '], ['\n    padding-right: ', 'px;\n    padding-left: ', 'px;\n  ']);

var width = styled.css(_templateObject$1, function (p) {
  return !p.fluid && Object.keys(maxContainer).map(function (key) {
    return breakpointUp(key)(_templateObject2$1, maxContainer[key]);
  });
});

var Container = styled__default.div(_templateObject3$1, function (_ref) {
  var theme = _ref.theme;
  return styled.css(_templateObject4, getGridGutter(theme) / 2, getGridGutter(theme) / 2);
}, width);

Container.propTypes = {
  fluid: PropTypes.bool,
  gutter: PropTypes.number,
  children: PropTypes.node
};

var _templateObject$2 = taggedTemplateLiteral(['\n  display: flex;\n  flex-wrap: wrap;\n  ', '\n'], ['\n  display: flex;\n  flex-wrap: wrap;\n  ', '\n']),
    _templateObject2$2 = taggedTemplateLiteral(['\n    margin-right: ', 'px;\n    margin-left: ', 'px;\n    ', '\n  \n    ', '\n  \n    ', '\n  \n    ', '\n  \n    ', '\n  \n    ', '\n  \n    ', '\n  \n    ', '\n  \n    ', '\n  '], ['\n    margin-right: ', 'px;\n    margin-left: ', 'px;\n    ', '\n  \n    ', '\n  \n    ', '\n  \n    ', '\n  \n    ', '\n  \n    ', '\n  \n    ', '\n  \n    ', '\n  \n    ', '\n  ']),
    _templateObject3$2 = taggedTemplateLiteral(['\n      justify-content: flex-start;\n    '], ['\n      justify-content: flex-start;\n    ']),
    _templateObject4$1 = taggedTemplateLiteral(['\n      justify-content: center;\n    '], ['\n      justify-content: center;\n    ']),
    _templateObject5 = taggedTemplateLiteral(['\n      justify-content: flex-end;\n    '], ['\n      justify-content: flex-end;\n    ']),
    _templateObject6 = taggedTemplateLiteral(['\n      align-items: flex-start;\n    '], ['\n      align-items: flex-start;\n    ']),
    _templateObject7 = taggedTemplateLiteral(['\n      align-items: center;\n    '], ['\n      align-items: center;\n    ']),
    _templateObject8 = taggedTemplateLiteral(['\n      align-items: flex-end;\n    '], ['\n      align-items: flex-end;\n    ']),
    _templateObject9 = taggedTemplateLiteral(['\n      justify-content: space-around;\n    '], ['\n      justify-content: space-around;\n    ']),
    _templateObject10 = taggedTemplateLiteral(['\n      justify-content: space-between;\n    '], ['\n      justify-content: space-between;\n    ']);

var valueType = PropTypes.oneOf(Object.keys(breakpoints));

var Row = styled__default.div(_templateObject$2, function (p) {
  return styled.css(_templateObject2$2, getGridGutter(p.theme) / -2, getGridGutter(p.theme) / -2, p.reverse && 'flex-direction: row-reverse;', p.start && breakpointUp(p.start)(_templateObject3$2), p.center && breakpointUp(p.center)(_templateObject4$1), p.end && breakpointUp(p.end)(_templateObject5), p.top && breakpointUp(p.top)(_templateObject6), p.middle && breakpointUp(p.middle)(_templateObject7), p.bottom && breakpointUp(p.bottom)(_templateObject8), p.around && breakpointUp(p.around)(_templateObject9), p.between && breakpointUp(p.between)(_templateObject10));
});

Row.propTypes = {
  reverse: PropTypes.bool,
  start: valueType,
  center: valueType,
  end: valueType,
  top: valueType,
  middle: valueType,
  bottom: valueType,
  around: valueType,
  between: valueType,
  children: PropTypes.node
};

var _templateObject$3 = taggedTemplateLiteral(['\n  ', '\n'], ['\n  ', '\n']),
    _templateObject2$3 = taggedTemplateLiteral(['\n            flex: 0 0 ', '%;\n            max-width: ', '%;\n            display: block;'], ['\n            flex: 0 0 ', '%;\n            max-width: ', '%;\n            display: block;']),
    _templateObject3$3 = taggedTemplateLiteral(['\n            flex-grow: 1;\n            flex-basis: 0;\n            max-width: 100%;\n            display: block;'], ['\n            flex-grow: 1;\n            flex-basis: 0;\n            max-width: 100%;\n            display: block;']),
    _templateObject4$2 = taggedTemplateLiteral(['display: none;'], ['display: none;']),
    _templateObject5$1 = taggedTemplateLiteral(['\n          margin-', ': \n          ', '%;'], ['\n          margin-', ': \n          ', '%;']),
    _templateObject6$1 = taggedTemplateLiteral(['\n  position: relative;\n  width: 100%;\n  min-height: 1px;\n  padding-right: ', 'px;\n  padding-left: ', 'px;\n  ', '\n  ', '\n  ', '\n  ', '\n  ', '\n'], ['\n  position: relative;\n  width: 100%;\n  min-height: 1px;\n  padding-right: ', 'px;\n  padding-left: ', 'px;\n  ', '\n  ', '\n  ', '\n  ', '\n  ', '\n']);

var valueType$1 = PropTypes.oneOfType([PropTypes.number, PropTypes.bool]);
var BP = Object.keys(breakpoints);
var offsetProps = BP.map(function (d) {
  return d + 'Offset';
});
var DimensionPropTypes = BP.reduce(function (propTypes, dimension) {
  propTypes[dimension] = valueType$1;
  propTypes[dimension + 'Offset'] = PropTypes.number;
  return propTypes;
}, {});

var colData = styled.css(_templateObject$3, function (p) {
  return Object.keys(p).filter(function (k) {
    return ~BP.indexOf(k);
  }).sort(function (k1, k2) {
    return BP.indexOf(k1) - BP.indexOf(k2);
  }).map(function (k) {
    if (Number.isInteger(p[k])) {
      return breakpointUp(k)(_templateObject2$3, 100 / getGridSize(p.theme) * p[k], 100 / getGridSize(p.theme) * p[k]);
    } else if (p[k]) {
      return breakpointUp(k)(_templateObject3$3);
    } else {
      return breakpointUp(k)(_templateObject4$2);
    }
  });
});
var offset = styled.css(_templateObject$3, function (p) {
  return Object.keys(p).filter(function (k) {
    return ~offsetProps.indexOf(k);
  }).map(function (k) {
    return breakpointUp(k.replace(/Offset$/, ''))(_templateObject5$1, p.theme.dir == 'rtl' ? 'right' : 'left', 100 / getGridSize(p.theme) * p[k]);
  });
});
var Col = styled__default.div(_templateObject$3, function (_ref) {
  var theme = _ref.theme,
      first = _ref.first,
      last = _ref.last,
      order = _ref.order;
  return styled.css(_templateObject6$1, getGridGutter(theme) / 2, getGridGutter(theme) / 2, colData, offset, first && 'order: -1;', last && 'order: ' + (getGridSize(theme) + 1) + ';', order && 'order: ' + order + ';');
});

Col.propTypes = _extends({}, DimensionPropTypes, {
  first: PropTypes.bool,
  last: PropTypes.bool,
  order: PropTypes.number,
  children: PropTypes.node
});

exports.Container = Container;
exports.Row = Row;
exports.Col = Col;
