'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var styled = require('styled-components');
var styled__default = _interopDefault(styled);
var PropTypes = _interopDefault(require('prop-types'));
var React = _interopDefault(require('react'));

var taggedTemplateLiteral = function (strings, raw) {
  return Object.freeze(Object.defineProperties(strings, {
    raw: {
      value: Object.freeze(raw)
    }
  }));
};

var toConsumableArray = function (arr) {
  if (Array.isArray(arr)) {
    for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) arr2[i] = arr[i];

    return arr2;
  } else {
    return Array.from(arr);
  }
};

/*
 * @license
 * Copyright OAH Technology. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */

var badge = PropTypes.shape({
  status: colorState,
  title: PropTypes.string,
  position: position
});
var position = PropTypes.oneOf(['topRight', 'topLeft', 'bottomRight', 'bottomLeft', 'topStart', 'topEnd', 'bottomStart', 'bottomEnd']);

var colorState = PropTypes.oneOf(['Info', 'Success', 'Danger', 'Primary', 'Warning', 'Disabled']);

var placement = PropTypes.oneOf(['start', 'end', 'right', 'left', 'top', 'bottom']);

var trigger = PropTypes.oneOf(['click', 'hover', 'focus']);

var statusArray = ['Info', 'Success', 'Danger', 'Primary', 'Warning'];

var size = PropTypes.oneOf(['XXS', 'XS', 'SM', 'MD', 'LG', 'XL', 'XXL']);

var shape = PropTypes.oneOf(['Rectangle', 'SemiRound', 'Round']);

var itemType = {
  title: PropTypes.string.isRequired,
  link: PropTypes.any,
  expanded: PropTypes.bool,
  group: PropTypes.bool,
  hidden: PropTypes.bool,
  icon: PropTypes.string,
  target: PropTypes.string,
  url: PropTypes.string
};

var buttonTypes = {
  fullWidth: PropTypes.bool,
  hero: PropTypes.bool,
  outline: PropTypes.bool,
  pulse: PropTypes.bool,
  size: PropTypes.oneOf(['XS', 'SM', 'MD', 'LG']),
  shape: shape,
  status: PropTypes.oneOf([].concat(statusArray, ['Secondary']))
};

var _templateObject = taggedTemplateLiteral(['\n  ', '\n'], ['\n  ', '\n']),
    _templateObject2 = taggedTemplateLiteral(['\n    overflow: hidden;\n    display: block;\n    height: ', ';\n    border-radius: ', ';\n    background-color: ', ';\n    .progress-value {\n      height: 100%;\n      width: ', '%;\n      text-align: center;\n      overflow: hidden;\n      background-color: ', ';\n      color: ', ';\n      font-size: ', ';\n      font-weight: ', ';\n      line-height: ', ';\n      transition-duration: ', ';\n      transition-property: width, background-color;\n    }\n  '], ['\n    overflow: hidden;\n    display: block;\n    height: ', ';\n    border-radius: ', ';\n    background-color: ', ';\n    .progress-value {\n      height: 100%;\n      width: ', '%;\n      text-align: center;\n      overflow: hidden;\n      background-color: ', ';\n      color: ', ';\n      font-size: ', ';\n      font-weight: ', ';\n      line-height: ', ';\n      transition-duration: ', ';\n      transition-property: width, background-color;\n    }\n  ']);

var ProgressStyle = styled__default.div(_templateObject, function (_ref) {
  var theme = _ref.theme,
      size$$1 = _ref.size,
      status = _ref.status,
      value = _ref.value;
  return styled.css(_templateObject2, theme['progressBarHeight' + size$$1], theme.progressBarRadius, theme.progressBarBg, value, theme['progressBar' + status + 'Bg'], theme.progressBarFontColor, theme['progressBarFontSize' + size$$1], theme.progressBarFontWeight, theme.progressBarLineHeight, theme.progressBarAnimationDuration);
});

function Progress(props) {
  return React.createElement(
    ProgressStyle,
    props,
    React.createElement(
      'div',
      { className: 'progress-value' },
      props.displayValue && React.createElement(
        'span',
        null,
        props.value,
        '%'
      ),
      props.children
    )
  );
}

Progress.defaultProps = {
  size: 'MD',
  status: 'Default',
  value: 0
};

Progress.propTypes = {
  size: PropTypes.oneOf(['XS', 'SM', 'MD', 'LG', 'XL']),
  status: PropTypes.oneOf([].concat(toConsumableArray(statusArray), ['Default'])),
  value: PropTypes.number,
  displayValue: PropTypes.bool
};

module.exports = Progress;
