'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var styled = require('styled-components');
var styled__default = _interopDefault(styled);
var PropTypes = _interopDefault(require('prop-types'));
var React = _interopDefault(require('react'));

var taggedTemplateLiteral = function (strings, raw) {
  return Object.freeze(Object.defineProperties(strings, {
    raw: {
      value: Object.freeze(raw)
    }
  }));
};

var toConsumableArray = function (arr) {
  if (Array.isArray(arr)) {
    for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) arr2[i] = arr[i];

    return arr2;
  } else {
    return Array.from(arr);
  }
};

/*
 * @license
 * Copyright OAH Technology. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */

var badge = PropTypes.shape({
  status: colorState,
  title: PropTypes.string,
  position: position
});
var position = PropTypes.oneOf(['topRight', 'topLeft', 'bottomRight', 'bottomLeft', 'topStart', 'topEnd', 'bottomStart', 'bottomEnd']);

var colorState = PropTypes.oneOf(['Info', 'Success', 'Danger', 'Primary', 'Warning', 'Disabled']);

var placement = PropTypes.oneOf(['start', 'end', 'right', 'left', 'top', 'bottom']);

var trigger = PropTypes.oneOf(['click', 'hover', 'focus']);

var statusArray = ['Info', 'Success', 'Danger', 'Primary', 'Warning'];

var size = PropTypes.oneOf(['XXS', 'XS', 'SM', 'MD', 'LG', 'XL', 'XXL']);

var shape = PropTypes.oneOf(['Rectangle', 'SemiRound', 'Round']);

var itemType = {
  title: PropTypes.string.isRequired,
  link: PropTypes.any,
  expanded: PropTypes.bool,
  group: PropTypes.bool,
  hidden: PropTypes.bool,
  icon: PropTypes.string,
  target: PropTypes.string,
  url: PropTypes.string
};

var buttonTypes = {
  fullWidth: PropTypes.bool,
  hero: PropTypes.bool,
  outline: PropTypes.bool,
  pulse: PropTypes.bool,
  size: PropTypes.oneOf(['XS', 'SM', 'MD', 'LG']),
  shape: shape,
  status: PropTypes.oneOf([].concat(statusArray, ['Secondary']))
};

var _templateObject = taggedTemplateLiteral(['\n  0% {\n    transform: rotate(0deg);\n  }\n  40% {\n    transform: rotate(230deg);\n  }\n  100% {\n    transform: rotate(360deg);\n  }\n'], ['\n  0% {\n    transform: rotate(0deg);\n  }\n  40% {\n    transform: rotate(230deg);\n  }\n  100% {\n    transform: rotate(360deg);\n  }\n']),
    _templateObject2 = taggedTemplateLiteral(['\n  ', '\n'], ['\n  ', '\n']),
    _templateObject3 = taggedTemplateLiteral(['\n    opacity: 1;\n    position: absolute;\n    border-radius: inherit;\n    top: 0;\n    right: 0;\n    left: 0;\n    bottom: 0;\n    overflow: hidden;\n    z-index: 999;\n    display: flex;\n    justify-content: center;\n    align-items: center;\n    visibility: visible;\n    background-color: ', ';\n     ', ';\n    }\n\n    .spin-circle {\n      animation: ', ' 0.8s infinite linear;\n      border-radius: 50%;\n      border-style: solid;\n      border-width: 0.125em;\n      width: 1em;\n      height: 1em;\n      border-left-color: ', ';\n      border-top-color: ', ';\n      border-bottom-color: ', ';\n      ', '\n    }\n\n    .message {\n      margin-left: 0.5rem;\n      line-height: 1rem;\n      font-size: 1rem;\n      color: ', ';\n    }\n  '], ['\n    opacity: 1;\n    position: absolute;\n    border-radius: inherit;\n    top: 0;\n    right: 0;\n    left: 0;\n    bottom: 0;\n    overflow: hidden;\n    z-index: 999;\n    display: flex;\n    justify-content: center;\n    align-items: center;\n    visibility: visible;\n    background-color: ', ';\n     ', ';\n    }\n\n    .spin-circle {\n      animation: ', ' 0.8s infinite linear;\n      border-radius: 50%;\n      border-style: solid;\n      border-width: 0.125em;\n      width: 1em;\n      height: 1em;\n      border-left-color: ', ';\n      border-top-color: ', ';\n      border-bottom-color: ', ';\n      ', '\n    }\n\n    .message {\n      margin-left: 0.5rem;\n      line-height: 1rem;\n      font-size: 1rem;\n      color: ', ';\n    }\n  ']);

var spin = styled.keyframes(_templateObject);

var SpinnerStyle = styled__default.div(_templateObject2, function (_ref) {
  var theme = _ref.theme,
      size$$1 = _ref.size,
      status = _ref.status;
  return styled.css(_templateObject3, theme.spinnerBg, size$$1 && 'font-size: ' + theme['spinner' + size$$1], spin, theme.spinnerCircleBg, theme.spinnerCircleBg, theme.spinnerCircleBg, status && 'border-right-color: ' + theme['spinner' + status + 'Bg'] + ';', theme.spinnerFg);
});

function Spinner(props) {
  return React.createElement(
    SpinnerStyle,
    props,
    React.createElement('span', { className: 'spin-circle' }),
    React.createElement(
      'span',
      { className: 'message' },
      props.children
    )
  );
}
Spinner.propTypes = {
  size: size,
  status: PropTypes.oneOf([].concat(toConsumableArray(statusArray), ['Active', 'Disabled']))
};

module.exports = Spinner;
