'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var PropTypes = _interopDefault(require('prop-types'));
var styled = require('styled-components');
var styled__default = _interopDefault(styled);
var React = _interopDefault(require('react'));

var taggedTemplateLiteral = function (strings, raw) {
  return Object.freeze(Object.defineProperties(strings, {
    raw: {
      value: Object.freeze(raw)
    }
  }));
};

/*
 * @license
 * Copyright OAH Technology. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */

var badge = PropTypes.shape({
  status: colorState,
  title: PropTypes.string,
  position: position
});
var position = PropTypes.oneOf(['topRight', 'topLeft', 'bottomRight', 'bottomLeft', 'topStart', 'topEnd', 'bottomStart', 'bottomEnd']);

var colorState = PropTypes.oneOf(['Info', 'Success', 'Danger', 'Primary', 'Warning', 'Disabled']);

var placement = PropTypes.oneOf(['start', 'end', 'right', 'left', 'top', 'bottom']);

var trigger = PropTypes.oneOf(['click', 'hover', 'focus']);

var statusArray = ['Info', 'Success', 'Danger', 'Primary', 'Warning'];

var size = PropTypes.oneOf(['XXS', 'XS', 'SM', 'MD', 'LG', 'XL', 'XXL']);

var shape = PropTypes.oneOf(['Rectangle', 'SemiRound', 'Round']);

var itemType = {
  title: PropTypes.string.isRequired,
  link: PropTypes.any,
  expanded: PropTypes.bool,
  group: PropTypes.bool,
  hidden: PropTypes.bool,
  icon: PropTypes.string,
  target: PropTypes.string,
  url: PropTypes.string
};

var buttonTypes = {
  fullWidth: PropTypes.bool,
  hero: PropTypes.bool,
  outline: PropTypes.bool,
  pulse: PropTypes.bool,
  size: PropTypes.oneOf(['XS', 'SM', 'MD', 'LG']),
  shape: shape,
  status: PropTypes.oneOf([].concat(statusArray, ['Secondary']))
};

function getPhysicalPosition(dir, position) {
  if (position1.includes(position) || position3.includes(position)) {
    return position;
  }
  switch (position) {
    case 'start':
      return dir === 'rtl' ? 'right' : 'left';
    case 'end':
      return dir === 'rtl' ? 'left' : 'right';
    case 'topStart':
      return dir === 'rtl' ? 'topRight' : 'topLeft';
    case 'topEnd':
      return dir === 'rtl' ? 'topLeft' : 'topRight';
    case 'bottomStart':
      return dir === 'rtl' ? 'bottomRight' : 'bottomLeft';
    case 'bottomEnd':
      return dir === 'rtl' ? 'bottomLeft' : 'bottomRight';
  }
  return position;
}

var position1 = ['left', 'right', 'top', 'bottom'];
var position3 = ['topRight', 'topLeft', 'bottomRight', 'bottomLeft'];

var _templateObject = taggedTemplateLiteral(['\n  ', '\n  ', '\n'], ['\n  ', '\n  ', '\n']),
    _templateObject2 = taggedTemplateLiteral(['\n    color: ', ';\n    position: absolute;\n    padding: 0.25em 0.4em;\n    font-size: 75%;\n    font-weight: 700;\n    line-height: 1;\n    text-align: center;\n    white-space: nowrap;\n    vertical-align: baseline;\n    border-radius: 0.25rem;\n    background-color: ', ';\n  '], ['\n    color: ', ';\n    position: absolute;\n    padding: 0.25em 0.4em;\n    font-size: 75%;\n    font-weight: 700;\n    line-height: 1;\n    text-align: center;\n    white-space: nowrap;\n    vertical-align: baseline;\n    border-radius: 0.25rem;\n    background-color: ', ';\n  ']);

var Badge = styled__default.span(_templateObject, function (_ref) {
  var theme = _ref.theme,
      status = _ref.status;
  return styled.css(_templateObject2, theme.badgeFgText, theme['badge' + status + 'BgColor']);
}, function (_ref2) {
  var position$$1 = _ref2.position,
      theme = _ref2.theme;

  var placement$$1 = getPhysicalPosition(theme.dir, position$$1);
  switch (placement$$1) {
    case 'topRight':
      return 'top: 0;right: 0;';
    case 'topLeft':
      return 'top: 0;left: 0;';
    case 'bottomRight':
      return 'bottom: 0;right: 0;';
    case 'bottomLeft':
      return 'bottom: 0;left: 0;';
  }
});
Badge.propTypes = {
  position: position,
  status: colorState
};

var _templateObject$1 = taggedTemplateLiteral(['\n  ', '\n'], ['\n  ', '\n']),
    _templateObject2$1 = taggedTemplateLiteral(['\n    font-size: ', ';\n    line-height: ', ';\n    display: flex;\n\n    .user-container {\n      position: relative;\n      display: flex;\n      align-items: center;\n    }\n\n    .user-picture {\n      background: ', ';\n      border: solid 2px ', ';\n      position: relative;\n      border-radius: 50%;\n      flex-shrink: 0;\n      ', '\n\n      &.background {\n        color: ', ';\n        display: flex;\n        align-items: center;\n        justify-content: center;\n        ', '\n      }\n      &.image {\n      ', '\n        background-size: cover;\n        background-repeat: no-repeat;\n      }\n    }\n\n    .user-name {\n      font-family: ', ';\n    }\n\n    .user-title {\n      font-size: 0.75rem;\n    }\n\n    .user-name,\n    .user-title {\n      text-align: ', ';\n    }\n\n    .info-container {\n      margin-', ': 0.5rem;\n    }\n\n    &.inverse {\n      .user-picture {\n        background: ', ';\n\n        &.background {\n          color: ', ';\n        }\n      }\n    }\n  '], ['\n    font-size: ', ';\n    line-height: ', ';\n    display: flex;\n\n    .user-container {\n      position: relative;\n      display: flex;\n      align-items: center;\n    }\n\n    .user-picture {\n      background: ', ';\n      border: solid 2px ', ';\n      position: relative;\n      border-radius: 50%;\n      flex-shrink: 0;\n      ', '\n\n      &.background {\n        color: ', ';\n        display: flex;\n        align-items: center;\n        justify-content: center;\n        ', '\n      }\n      &.image {\n      ', '\n        background-size: cover;\n        background-repeat: no-repeat;\n      }\n    }\n\n    .user-name {\n      font-family: ', ';\n    }\n\n    .user-title {\n      font-size: 0.75rem;\n    }\n\n    .user-name,\n    .user-title {\n      text-align: ', ';\n    }\n\n    .info-container {\n      margin-', ': 0.5rem;\n    }\n\n    &.inverse {\n      .user-picture {\n        background: ', ';\n\n        &.background {\n          color: ', ';\n        }\n      }\n    }\n  ']),
    _templateObject3 = taggedTemplateLiteral(['\n          height: ', ';\n          width: ', ';\n          ', '\n        '], ['\n          height: ', ';\n          width: ', ';\n          ', '\n        ']);

var UserStyle = styled__default.div(_templateObject$1, function (_ref) {
  var theme = _ref.theme,
      size = _ref.size,
      image = _ref.image,
      color = _ref.color;
  return styled.css(_templateObject2$1, theme.userFontSize, theme.userLineHeight, theme.userBg, theme.userFgHighlight, size && styled.css(_templateObject3, theme['userSize' + size], theme['userSize' + size], size === 'Small' && 'font-size: 80%;'), theme.userFg, color && 'background-color: ' + color + ';', image && 'background-image: ' + image + ';', theme.userFontFamilySecondary, theme.dir === 'rtl' ? 'right' : 'left', theme.dir === 'rtl' ? 'right' : 'left', theme.userFg, theme.userBg);
});

/*
 * @license
 * Copyright OAH Technology. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */

function User(props) {
  var getInitials = function getInitials() {
    if (props.name) {
      var names = props.name.split(' ');

      return names.map(function (n) {
        return n.charAt(0);
      }).splice(0, 2).join('').toUpperCase();
    }

    return '';
  };
  return React.createElement(
    UserStyle,
    props,
    React.createElement(
      'div',
      { className: 'user-container' },
      React.createElement(
        'div',
        {
          className: 'user-picture ' + (props.image ? 'image' : 'background')
        },
        !props.image && props.showInitials && getInitials(),
        props.badge && React.createElement(
          Badge,
          { status: props.badge.status, position: props.badge.position },
          props.badge.title
        )
      ),
      !props.onlyPicture && React.createElement(
        'div',
        { className: 'info-container' },
        React.createElement(
          'div',
          { className: 'user-name' },
          props.name
        ),
        React.createElement(
          'div',
          { className: 'user-title' },
          props.title
        )
      )
    )
  );
}
User.defaultProps = {
  size: 'MD',
  showInitials: true
};

User.propTypes = {
  size: PropTypes.oneOf(['SM', 'MD', 'LG', 'XL']),
  name: PropTypes.string,
  title: PropTypes.string,
  color: PropTypes.string,
  image: PropTypes.string,
  showInitials: PropTypes.bool,
  onlyPicture: PropTypes.bool,
  inverse: PropTypes.bool,
  badge: PropTypes.object
};

module.exports = User;
